==> zio-aws-rds_3-5.17.127.2-sources.jar: zio/aws/rds/model/StopDbInstanceAutomatedBackupsReplicationResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class StopDbInstanceAutomatedBackupsReplicationResponse(
    dbInstanceAutomatedBackup: scala.Option[
      zio.aws.rds.model.DBInstanceAutomatedBackup
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse = {
    import StopDbInstanceAutomatedBackupsReplicationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse
      .builder()
      .optionallyWith(
        dbInstanceAutomatedBackup.map(value => value.buildAwsValue())
      )(_.dbInstanceAutomatedBackup)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse.ReadOnly =
    zio.aws.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse
      .wrap(buildAwsValue())
}
object StopDbInstanceAutomatedBackupsReplicationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse =
      zio.aws.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse(
        dbInstanceAutomatedBackup.map(value => value.asEditable)
      )
    def dbInstanceAutomatedBackup
        : scala.Option[zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly]
    def getDbInstanceAutomatedBackup: ZIO[
      Any,
      AwsError,
      zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly
    ] = AwsError.unwrapOptionField(
      "dbInstanceAutomatedBackup",
      dbInstanceAutomatedBackup
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse
  ) extends zio.aws.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse.ReadOnly {
    override val dbInstanceAutomatedBackup
        : scala.Option[zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly] =
      scala
        .Option(impl.dbInstanceAutomatedBackup())
        .map(value => zio.aws.rds.model.DBInstanceAutomatedBackup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse
  ): zio.aws.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-rds_3-5.17.295.12-sources.jar: zio/aws/rds/model/StopDbInstanceAutomatedBackupsReplicationResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class StopDbInstanceAutomatedBackupsReplicationResponse(
    dbInstanceAutomatedBackup: Optional[
      zio.aws.rds.model.DBInstanceAutomatedBackup
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse = {
    import StopDbInstanceAutomatedBackupsReplicationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse
      .builder()
      .optionallyWith(
        dbInstanceAutomatedBackup.map(value => value.buildAwsValue())
      )(_.dbInstanceAutomatedBackup)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse.ReadOnly =
    zio.aws.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse
      .wrap(buildAwsValue())
}
object StopDbInstanceAutomatedBackupsReplicationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse =
      zio.aws.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse(
        dbInstanceAutomatedBackup.map(value => value.asEditable)
      )
    def dbInstanceAutomatedBackup
        : Optional[zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly]
    def getDbInstanceAutomatedBackup: ZIO[
      Any,
      AwsError,
      zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly
    ] = AwsError.unwrapOptionField(
      "dbInstanceAutomatedBackup",
      dbInstanceAutomatedBackup
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse
  ) extends zio.aws.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse.ReadOnly {
    override val dbInstanceAutomatedBackup
        : Optional[zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbInstanceAutomatedBackup())
        .map(value => zio.aws.rds.model.DBInstanceAutomatedBackup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse
  ): zio.aws.rds.model.StopDbInstanceAutomatedBackupsReplicationResponse.ReadOnly =
    new Wrapper(impl)
}
